tiled.structures.dataframe.DataFrameMicroStructure
==================================================

.. currentmodule:: tiled.structures.dataframe

.. autoclass:: DataFrameMicroStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataFrameMicroStructure.__init__
      ~DataFrameMicroStructure.from_dask_dataframe
   
   

   
   
   